@@ -19,7 +19,7 @@ class OscMessage(object):
 
     def __init__(self, dgram: bytes) -> None:
         self._dgram = dgram
-        self._parameters = []
+        self._parameters = []  # type: List[Any]
         self._parse_datagram()
 
     def _parse_datagram(self) -> None:
@@ -34,10 +34,11 @@ class OscMessage(object):
             if type_tag.startswith(','):
                 type_tag = type_tag[1:]
 
-            params = []
+            params = []  # type: List[Any]
             param_stack = [params]
             # Parse each parameter given its type.
             for param in type_tag:
+                val = NotImplemented  # type: Any
                 if param == "i":  # Integer.
                     val, index = osc_types.get_int(self._dgram, index)
                 elif param == "h":  # Int64.
@@ -60,8 +61,10 @@ class OscMessage(object):
                     val = True
                 elif param == "F":  # False.
                     val = False
+                elif param == "N":  # Nil.
+                    val = None
                 elif param == "[":  # Array start.
-                    array = []
+                    array = []  # type: List[Any]
                     param_stack[-1].append(array)
                     param_stack.append(array)
                 elif param == "]":  # Array stop.
@@ -105,6 +108,6 @@ class OscMessage(object):
         """Convenience method for list(self) to get the list of parameters."""
         return list(self)
 
-    def __iter__(self) -> Iterator[float]:
+    def __iter__(self) -> Iterator[Any]:
         """Returns an iterator over the parameters of this message."""
         return iter(self._parameters)
