@@ -11,8 +11,11 @@ from pythonosc.dispatcher import Dispatcher
 
 from asyncio import BaseEventLoop
 
-from typing import List, Tuple
-from types import coroutine
+from socket import socket as _socket
+from typing import Any, Tuple, Union, cast, Coroutine
+
+_RequestType = Union[_socket, Tuple[bytes, _socket]]
+_AddressType = Union[Tuple[str, int], str]
 
 
 class _UDPHandler(socketserver.BaseRequestHandler):
@@ -26,15 +29,17 @@ class _UDPHandler(socketserver.BaseRequestHandler):
         If not the server won't call it and so no new
         threads/processes will be spawned.
         """
-        self.server.dispatcher.call_handlers_for_packet(self.request[0], self.client_address)
+        server = cast(OSCUDPServer, self.server)
+        server.dispatcher.call_handlers_for_packet(self.request[0], self.client_address)
 
 
-def _is_valid_request(request: List[bytes]) -> bool:
+def _is_valid_request(request: _RequestType) -> bool:
     """Returns true if the request's data looks like an osc bundle or message.
 
     Returns:
         True if request is OSC bundle or OSC message
     """
+    assert isinstance(request, tuple)  # TODO: handle requests which are passed just as a socket?
     data = request[0]
     return (
             osc_bundle.OscBundle.dgram_is_bundle(data)
@@ -44,7 +49,7 @@ def _is_valid_request(request: List[bytes]) -> bool:
 class OSCUDPServer(socketserver.UDPServer):
     """Superclass for different flavors of OSC UDP servers"""
 
-    def __init__(self, server_address: Tuple[str, int], dispatcher: Dispatcher, bind_and_activate=True) -> None:
+    def __init__(self, server_address: Tuple[str, int], dispatcher: Dispatcher, bind_and_activate: bool = True) -> None:
         """Initialize
 
         Args:
@@ -55,7 +60,7 @@ class OSCUDPServer(socketserver.UDPServer):
         super().__init__(server_address, _UDPHandler, bind_and_activate)
         self._dispatcher = dispatcher
 
-    def verify_request(self, request: List[bytes], client_address: Tuple[str, int]) -> bool:
+    def verify_request(self, request: _RequestType, client_address: _AddressType) -> bool:
         """Returns true if the data looks like a valid OSC UDP datagram
 
         Args:
@@ -136,7 +141,7 @@ class AsyncIOOSCUDPServer():
         """
         self._loop.run_until_complete(self.create_serve_endpoint())
 
-    def create_serve_endpoint(self) -> coroutine:
+    def create_serve_endpoint(self) -> Coroutine[Any, Any, Tuple[asyncio.transports.BaseTransport, asyncio.DatagramProtocol]]:
         """Creates a datagram endpoint and registers it with event loop as coroutine.
 
         Returns:
